@@ -236,4 +236,4 @@ class parameterized(object):
 
     @classmethod
     def to_safe_name(cls, s):
-        return str(re.sub("[^a-zA-Z0-9_]", "", s))
+        return str(re.sub("[^a-zA-Z0-9_]+", "_", s))
